@@ -21,6 +21,8 @@ def assert_data_equal(df1, df2, index=None, **kwargs):
     Compares two dataframes, ignoring the order of rows and columns.
     As a shortcut, you can pass `index` to set a common index on the two dataframes.
     If you use the default integer index, it may not know what row order is meaningful.
+    You can also pass arguments to the underlying assert_frame_equal function,
+    such as check_dtype=False.
     Eg.
     >>> df1 = DataFrame(index = [1,3,2,4])
     >>> df2 = DataFrame(index = [1,2,3,4])
